@@ -29,7 +29,11 @@ HEADERS = {
     "Accept": "application/xhtml+xml,application/xml,*/*",
     "Accept-Language": "en-US,en;q=0.9",
     "Cache-Control": "max-age=0",
-    "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/89.0.4389.114 Safari/537.36",
+    "User-Agent": (
+        "Mozilla/5.0 (Windows NT 10.0; Win64; x64) "
+        "AppleWebKit/537.36 (KHTML, like Gecko) "
+        "Chrome/111.0.0.0 Safari/537.36"
+    ),
     "Connection": "keep-alive",
     "Content-Type": "application/xml; charset=utf-8",
 }
